# Form implementation generated from reading ui file '/Users/samschott/Python/maestral-qt/maestral_qt/resources/selective_sync_dialog.ui'
#
# Created by: PyQt6 UI code generator 6.1.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SelectiveSyncDialog(object):
    def setupUi(self, SelectiveSyncDialog):
        SelectiveSyncDialog.setObjectName("SelectiveSyncDialog")
        SelectiveSyncDialog.resize(690, 450)
        SelectiveSyncDialog.setModal(True)
        self.gridLayout = QtWidgets.QGridLayout(SelectiveSyncDialog)
        self.gridLayout.setContentsMargins(0, -1, 0, -1)
        self.gridLayout.setHorizontalSpacing(7)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 0, 2, 1)
        spacerItem1 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem1, 4, 4, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem2, 4, 0, 1, 1)
        self.treeViewFolders = QtWidgets.QTreeView(SelectiveSyncDialog)
        self.treeViewFolders.setEditTriggers(QtWidgets.QAbstractItemView.EditTrigger.NoEditTriggers)
        self.treeViewFolders.setAlternatingRowColors(True)
        self.treeViewFolders.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectionBehavior.SelectRows)
        self.treeViewFolders.setTextElideMode(QtCore.Qt.TextElideMode.ElideRight)
        self.treeViewFolders.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollMode.ScrollPerPixel)
        self.treeViewFolders.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollMode.ScrollPerItem)
        self.treeViewFolders.setUniformRowHeights(True)
        self.treeViewFolders.setSortingEnabled(True)
        self.treeViewFolders.setObjectName("treeViewFolders")
        self.treeViewFolders.header().setSortIndicatorShown(True)
        self.gridLayout.addWidget(self.treeViewFolders, 2, 0, 1, 5)
        spacerItem3 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem3, 0, 4, 2, 1)
        self.updateButton = QtWidgets.QPushButton(SelectiveSyncDialog)
        self.updateButton.setObjectName("updateButton")
        self.gridLayout.addWidget(self.updateButton, 4, 3, 1, 1)
        self.selectAllCheckBox = QtWidgets.QCheckBox(SelectiveSyncDialog)
        self.selectAllCheckBox.setObjectName("selectAllCheckBox")
        self.gridLayout.addWidget(self.selectAllCheckBox, 3, 1, 1, 1)
        self.cancelButton = QtWidgets.QPushButton(SelectiveSyncDialog)
        self.cancelButton.setObjectName("cancelButton")
        self.gridLayout.addWidget(self.cancelButton, 4, 2, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem4, 4, 1, 1, 1)
        self.label = QtWidgets.QLabel(SelectiveSyncDialog)
        self.label.setWordWrap(True)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 1, 1, 3)

        self.retranslateUi(SelectiveSyncDialog)
        QtCore.QMetaObject.connectSlotsByName(SelectiveSyncDialog)

    def retranslateUi(self, SelectiveSyncDialog):
        _translate = QtCore.QCoreApplication.translate
        SelectiveSyncDialog.setWindowTitle(_translate("SelectiveSyncDialog", "Dialog"))
        self.updateButton.setText(_translate("SelectiveSyncDialog", "Update"))
        self.selectAllCheckBox.setText(_translate("SelectiveSyncDialog", "Select all"))
        self.cancelButton.setText(_translate("SelectiveSyncDialog", "Cancel"))
        self.label.setText(_translate("SelectiveSyncDialog", "Select which files and folders you want to see on your computer. Any items you unselect won\'t be shown on this computer, but you can still access them on the Dropbox website."))
