# Form implementation generated from reading ui file '/Users/samschott/Python/maestral-qt/maestral_qt/resources/sync_event_widget.ui'
#
# Created by: PyQt6 UI code generator 6.1.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SyncEventWidget(object):
    def setupUi(self, SyncEventWidget):
        SyncEventWidget.setObjectName("SyncEventWidget")
        SyncEventWidget.resize(400, 62)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(SyncEventWidget.sizePolicy().hasHeightForWidth())
        SyncEventWidget.setSizePolicy(sizePolicy)
        SyncEventWidget.setMinimumSize(QtCore.QSize(400, 0))
        self.verticalLayout = QtWidgets.QVBoxLayout(SyncEventWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(SyncEventWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setStyleSheet(".QFrame {\n"
"border: 1px solid rgb(205, 203, 205);\n"
"background-color: rgb(255, 255, 255);\n"
"border-radius: 7px;\n"
"}")
        self.frame.setFrameShape(QtWidgets.QFrame.Shape.Box)
        self.frame.setFrameShadow(QtWidgets.QFrame.Shadow.Plain)
        self.frame.setObjectName("frame")
        self.gridLayout = QtWidgets.QGridLayout(self.frame)
        self.gridLayout.setContentsMargins(7, 10, 12, 10)
        self.gridLayout.setObjectName("gridLayout")
        self.infoLabel = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.infoLabel.sizePolicy().hasHeightForWidth())
        self.infoLabel.setSizePolicy(sizePolicy)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(109, 109, 109))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(109, 109, 109))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(127, 127, 127))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.WindowText, brush)
        self.infoLabel.setPalette(palette)
        self.infoLabel.setObjectName("infoLabel")
        self.gridLayout.addWidget(self.infoLabel, 1, 1, 1, 1)
        self.filenameLabel = QElidedLabel(self.frame)
        self.filenameLabel.setObjectName("filenameLabel")
        self.gridLayout.addWidget(self.filenameLabel, 0, 1, 1, 1)
        self.iconLabel = QtWidgets.QLabel(self.frame)
        self.iconLabel.setMinimumSize(QtCore.QSize(32, 32))
        self.iconLabel.setMaximumSize(QtCore.QSize(32, 32))
        self.iconLabel.setText("")
        self.iconLabel.setObjectName("iconLabel")
        self.gridLayout.addWidget(self.iconLabel, 0, 0, 2, 1, QtCore.Qt.AlignmentFlag.AlignHCenter)
        self.actionButton = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(30)
        sizePolicy.setVerticalStretch(30)
        sizePolicy.setHeightForWidth(self.actionButton.sizePolicy().hasHeightForWidth())
        self.actionButton.setSizePolicy(sizePolicy)
        self.actionButton.setMinimumSize(QtCore.QSize(30, 30))
        self.actionButton.setStyleSheet("QPushButton {\n"
"    border: none;\n"
"    background-color: none;\n"
"    color: rgb(68,133,243);\n"
"    font: bold\n"
"}")
        self.actionButton.setObjectName("actionButton")
        self.gridLayout.addWidget(self.actionButton, 0, 3, 2, 1)
        spacerItem = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 2, 2, 1)
        self.verticalLayout.addWidget(self.frame)

        self.retranslateUi(SyncEventWidget)
        QtCore.QMetaObject.connectSlotsByName(SyncEventWidget)

    def retranslateUi(self, SyncEventWidget):
        _translate = QtCore.QCoreApplication.translate
        SyncEventWidget.setWindowTitle(_translate("SyncEventWidget", "Form"))
        self.infoLabel.setText(_translate("SyncEventWidget", "Added date * parent folder"))
        self.filenameLabel.setText(_translate("SyncEventWidget", "Metamorphosis.txt"))
        self.actionButton.setText(_translate("SyncEventWidget", "•••"))
from maestral_qt.widgets import QElidedLabel
